"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const workerpool_1 = __importDefault(require("workerpool"));
const parser_1 = require("@babel/parser");
const generator_1 = __importDefault(require("@babel/generator"));
const traverse_1 = __importDefault(require("@babel/traverse"));
const ValidationTranspiler_1 = require("./ValidationTranspiler");
const ImportExportTranspiler_1 = require("./ImportExportTranspiler");
const CubeCheckDuplicatePropTranspiler_1 = require("./CubeCheckDuplicatePropTranspiler");
const CubePropContextTranspiler_1 = require("./CubePropContextTranspiler");
const ErrorReporter_1 = require("../ErrorReporter");
const LightweightSymbolResolver_1 = require("./LightweightSymbolResolver");
const LightweightNodeCubeDictionary_1 = require("./LightweightNodeCubeDictionary");
const cubeDictionary = new LightweightNodeCubeDictionary_1.LightweightNodeCubeDictionary();
const cubeSymbols = new LightweightSymbolResolver_1.LightweightSymbolResolver();
const errorsReport = new ErrorReporter_1.ErrorReporter(null, []);
const transpilers = {
    ValidationTranspiler: new ValidationTranspiler_1.ValidationTranspiler(),
    ImportExportTranspiler: new ImportExportTranspiler_1.ImportExportTranspiler(),
    CubeCheckDuplicatePropTranspiler: new CubeCheckDuplicatePropTranspiler_1.CubeCheckDuplicatePropTranspiler(),
    CubePropContextTranspiler: new CubePropContextTranspiler_1.CubePropContextTranspiler(cubeSymbols, cubeDictionary),
};
const transpile = (data) => {
    cubeDictionary.setCubeNames(data.cubeNames);
    cubeSymbols.setSymbols(data.cubeSymbolsNames);
    const ast = (0, parser_1.parse)(data.content, {
        sourceFilename: data.fileName,
        sourceType: 'module',
        plugins: ['objectRestSpread']
    });
    data.transpilers.forEach(transpilerName => {
        if (transpilers[transpilerName]) {
            errorsReport.inFile(data);
            (0, traverse_1.default)(ast, transpilers[transpilerName].traverseObject(errorsReport));
            errorsReport.exitFile();
        }
        else {
            throw new Error(`Transpiler ${transpilerName} not supported`);
        }
    });
    const content = (0, generator_1.default)(ast, {}, data.content).code;
    return {
        content,
        errors: errorsReport.getErrors(),
        warnings: errorsReport.getWarnings()
    };
};
workerpool_1.default.worker({
    transpile,
});
//# sourceMappingURL=transpiler_worker.js.map